@@ -69,7 +69,7 @@ void	voice_send(void)
 		fread ((char *)&send_pkt, 56, 1, in_dat);
         	if (send_pkt.B_header.seq == 0x80)
         	{
-                	fread ((char *)&send_pkt, 56, 1, in_dat);
+                //	fread ((char *)&send_pkt, 56, 1, in_dat);
                 	ConSend();
                 	ConnectWait = TRUE;
 			AckTimeOut = 0;
@@ -202,9 +202,6 @@ void    ConSend(void)
         sndAddr.sin_family = PF_INET;
         sndAddr.sin_port = db_port;
         sndAddr.sin_addr = dbIP;
-	Packet_ID = rand();
-	SndPacketIdSave[0] = (Packet_ID >> 8) & 0xff;
-	SndPacketIdSave[1] = Packet_ID & 0xff;
 	send_msg.PacketID[0] = SndPacketIdSave[0];
 	send_msg.PacketID[1] = SndPacketIdSave[1];
 	memcpy (&send_msg.srcCall, &client_call, 8);
@@ -248,16 +245,17 @@ int main(int argc, const char **argv){
         int     width;
         int     n;
 	int	k;
+	int	opt;
 	char	Send_Connect;
 	char	Recv_Connect;
         fd_set  readOk,Mask;
         struct  timeval timeout;
         socklen_t addrlen;
 	struct	packet	send_packet;
+	int	KeepAliveCnt;
 
 	// IP アドレス，ソケット，sockaddr_in 構造体
 	struct sockaddr_in dstAddr;
-	//struct	repMsg	reqConMsg;
 
  	struct hostent *hp;
   	char   buf[256];
@@ -272,6 +270,7 @@ int main(int argc, const char **argv){
 	srand ((unsigned) time (NULL));
 
 	config (argc, (char **)argv);
+	KeepAliveCnt = 0;
 
         if (cmd_mode == 0)
         {
@@ -376,6 +375,7 @@ int main(int argc, const char **argv){
 	if (width < udpSocket) width = udpSocket;
 	if (width < cmdin) width = cmdin;
 	width++;
+
 	Send_Connect = FALSE;
 	Recv_Connect = FALSE;
 	SendBack = FALSE;
@@ -423,6 +423,14 @@ int main(int argc, const char **argv){
 					DSTREQcnt ++;
 					if ((DSTREQcnt % 4) == 0) ReqSendSender();
                                 }
+				KeepAliveCnt++;
+				if (KeepAliveCnt > 2000)
+				{
+                                        reqConMsg.reqType = KeepAlive;
+					memset (&reqConMsg.Keep_Alive, 0x00, 3);
+                                        send (dstSocket, &reqConMsg, 4, 0);
+					KeepAliveCnt = 0;
+				}
 				if (SendBack)	voice_send();
 				break;
 			default:
