@@ -21,6 +21,7 @@
 #define         Ack             0x02
 #define         Nak             0x03            /* Busy */
 #define		NoRoute		0x04
+#define		KeepAlive	0x05
 #define         ReqEnd          0xff
 
 
@@ -107,6 +108,10 @@ struct	repMsg
 			unsigned char	PacketID[2];
 			unsigned char	RespFlags;
 		} ackConnect;
+		struct
+		{
+			char		reserve[3];
+		} Keep_Alive;
 	};
 };
 
